" Vim syntax file
" Language:	structured text file
if exists("b:current_syntax")
  finish
endif

" Markers
syn keyword	strcTodo	contained TODO FIXME XXX
syn match	strcMark	"/\*.\*/"
syn match	strcMarkGeorge	"/\*G\*/"
syn region	strcErr		matchgroup=strcErrC start="(?" skip="\n\|\\)" end=")" contains=TOP,strcScr
" Full-line tags
syn region	strcComment2	matchgroup=strcComment2C start="^/\*$" end="^ *\*/$"
syn match	strcCommB	"^#" nextgroup=strcComment
syn match	strcComment	".*" contains=strcMark,strcTodo,strcErr,strcMarkGeorge contained
syn region	strcDeleted	start="/\*\([^GK]\|[GK][^*]\)" end="\*/" containedin=strcErr contained 
syn match	strcSection	"^>\+\s*" nextgroup=strcSTitle
syn region	strcSTitle	start="[^> 	]" end="$" containedin=strcSection contained contains=TOP,strcList,strcNList,strcSection,strcDList
syn region	strcLItem	start="[ 	]\@<=[^ 	]" end="$" containedin=strcList,strcNList contained contains=TOP,strcList,strcNList,strcSection,strcDList
syn match	strcList	"^\.\+\s\+" nextgroup=strcLItem
syn match	strcNList	"^[0-9]\+\s\+" nextgroup=strcLItem
syn match	strcLSTAG	"^[.>0-9]\+" containedin=strcSection,strcList,strcNList contained transparent
syn region	strcDLItem	start="." end="$" contained contains=TOP,strcList,strcNList,strcSection,strcDList
syn match	strcDLTerm	"^|[^|]\+|" contains=TOP,strcList,strcNList,strcSection,strcDList nextgroup=strcDLItem
" Enclosures
syn region	strcTerm	matchgroup=strcTermC start="\[" end="\]" contains=TOP,strcTerm,strcFoot
syn match	strc1TName	"\[\@<=[^|<[>\]]*|" containedin=strcTerm contained
syn match	strcTName	"|\@<=[^<\][>]*|" containedin=strcTerm contained
syn region	strcFoot	matchgroup=strcFootC start="\[\[" end="\]\]" contains=TOP,strcTerm
syn region	strcRepl	matchgroup=strcReplC start="{" end="\\\@<!}" contains=strcScr,strcEntity
syn region	strcVRepl	matchgroup=strcVReplC start="\\\@<!{" end="}" contained contains=strcScr,strcEntity
syn region	strcQuote	matchgroup=strcQuoteC start="``" end="''" contains=TOP
syn region	strcString	matchgroup=strcStringC start=+"+ end=+"+ skip=+\\.+ contains=strcVRepl,strcEntity	" strcScr
syn region	strcSystem	matchgroup=strcSystemC start="\^" skip=+\\.+ end="\^" contains=strcVRepl,strcURL,strcEntity " strcScr
"syn region	strcEntity	start="\\\@<!&" skip="\\&" end="&"
" Commented out for entitires don't work now
"syn region	strcEntity	start="&" skip="\\&" end="&" contains=NONE
syn region	strcEntity	start="v3ryc00l" skip="\\&" end="&" contains=NONE
syn region	strcEmph	matchgroup=strcEmphC start="\<_" end="_\>"
" One-letter emphasis
syn match	strc1Emph	"_\([[:alpha:]]_\)\+"
" Keyword and terms
syn match	strcKWPipe	"|" containedin=strcKWName,strcTName,strc1TName contained
syn match	strcKWName	"|[^<>]*" containedin=strcKeyword contained
syn region	strcKeyword	matchgroup=strcKWC start="<" end=">" contains=strcQuote,strcQuoteC
" Labels and links
syn region	strcLink	matchgroup=strcLinkC start="@\@<!@@\@!" end="@" contains=strcURL oneline
syn match	strcURL		"[[:alpha:]]\+://[^ 	@]*"
syn match	strcLID		"[^@]\+" containedin=strcLabel,strcELabel,strcVLabel contained
syn match	strcLabel	"@@[^@]*@@"
syn match	strcExtern	"^@@\(\([^@]\|\\@\)\+@\)\{3\}@" contains=strcETitle,strcELabel 
syn match	strcETitle	"^@@\([^@]\|\\@\)\+@" contains=TOP,strcExtern,strcLabel,strcLink contained
syn match	strcELabel	"@\([^@]\|\\@\)\+@@$" contained
" Verbatim
syn match	strcVerb	"^@@\(\([^@]\|\\@\)\+@\)\{2\}@\n" nextgroup=strcVBody contains=strcVTitle,strcVLabel
syn match	strcVTitle	"^@@\([^@]\|\\@\)\+" contains=TOP contained
syn match	strcVLabel	"@\([^@]\|\\@\)\+@@$" contained
syn region	strcVBody	matchgroup=strcVerbC start="^" end="^@@$" contained
syn match	strcVHAt	"@" containedin=strcVTitle,strcVLabel,strcETitle,strcELabel contained
syn match	strcVBeg	"^@@" containedin=strcVTitle contained
syn match	strcEBeg	"^@@" containedin=strcETitle contained
" Last-defined patterns have higher priority
syn match	strcScr		"\\" transparent contains=NONE nextgroup=strcScrC
syn match	strcScrC	"." transparent contains=NONE contained
syn match	strcMDash	"--" transparent contains=NONE
syn match	strcNDash	"\>--\<" transparent contains=NONE
syn match	strcNBSP	"[~]" transparent contains=NONE

if !exists("did_structured_syntax_inits")
  command -nargs=+ HiLink hi def link <args>
  HiLink strcCommB		Comment
  HiLink strcComment		Comment
  HiLink strcComment2		Comment
  HiLink strcComment2C		Comment
  HiLink strcDeleted		SpecialComment
  HiLink strcTodo		Todo
  HiLink strcMarkGeorge		WarningMsg
  HiLink strcMark		MoreMsg
  HiLink strcErr		ErrorMsg
  HiLink strcErrC		ErrorMsg
  HiLink strcSection		Comment
  HiLink strcSTitle		Statement
  HiLink strcList		Question
  HiLink strcNList		Question
  HiLink strcDLTerm		Question
  HiLink strcKeyword		Statement
  HiLink strcKWC		Comment
  HiLink strcKWPipe		Comment
  HiLink strcKWName		Preproc
  HiLink strcTerm		Preproc
  HiLink strcTermC		Comment
  HiLink strc1TName		Statement
  HiLink strcTName		Type
  HiLink strcFoot		Preproc
  HiLink strcFootC		Comment
  HiLink strcReplC		Question
  HiLink strcVReplC		Question
  HiLink strcRepl		Question
  HiLink strcVRepl		Question
  HiLink strcQuote		String
  HiLink strcQuoteC		String
  HiLink strcString		String
  HiLink strcStringC		String
  HiLink strcSystem		Constant
  HiLink strcSystemC		Constant
  HiLink strcEmph		Type
  HiLink strcEmphC		Type
  HiLink strc1Emph		Type
  HiLink strcEntity		Visual
  HiLink strcLink		VisualNOS
  HiLink strcLinkC		Comment
  HiLink strcURL		VisualNOS
  HiLink strcLabel		Comment
  HiLink strcLID		Title
  HiLink strcVerb		ErrorMsg
  HiLink strcVTitle		Statement
  HiLink strcVLabel		Question
  HiLink strcVBody		Constant
  HiLink strcVerbC		Comment
  HiLink strcVHAt		Comment
  HiLink strcVBeg		Comment
  HiLink strcEBeg		Comment
  HiLink strcExtern		VisualNOS
  HiLink strcETitle		Statement
  HiLink strcELabel		Question
  delcommand HiLink
endif

syn sync fromstart
